* Substitute all instances of RPair used in actions\* files
   * Need to find a way to obtain same output using the react\_comp table
* Verify that results are compatible or at least make sense

FOUND IT: http://rest.kegg.jp/get/R00374
There is only one reaction class per reaction, which is the ye olde rpair main class!
